#include <SyFi.h>

using namespace GiNaC; 
using namespace SyFi; 
using namespace std; 

int main () { 
    
    initSyFi(2); 

    int order = 3; 

    ReferenceTriangle triangle("t"); 
    RaviartThomas vfe; 
    vfe.set_polygon(triangle); 
    vfe.set_order(order); 
    vfe.compute_basis_functions(); 

    DiscontinuousLagrange pfe; 
    pfe.set_polygon(triangle); 
    pfe.set_order(order); 
    pfe.compute_basis_functions(); 

    for (unsigned int i=0; i< vfe.nbf(); i++) 
        cout <<"vfe.N("<<i<<")="<<vfe.N(i)<<endl; 

    for (unsigned int i=0; i< pfe.nbf(); i++) 
        cout <<"pfe.N("<<i<<")="<<pfe.N(i)<<endl; 

    return 0; 
}







